@@ -1,9 +1,9 @@
 package Mira::Config;
-$Mira::Config::VERSION = '0.07';
 
 use strict;
 use warnings;
 use utf8;
+our $VERSION = $Mira::VERSION;
 
 use YAML;
 use File::Spec;
@@ -39,11 +39,21 @@ sub new {
       croak " ! - you are not in true path or --source is invalid path or /conf/config.yml isn't valid file";
     }
 
+    $self->{_default}->{root} = "/" unless (exists $self->{_default}->{root} and $self->{_default}->{root});
+    $self->{_default}->{root} =~ s{^(.*)?:/+}{/}g;
+    $self->{_default}->{root} =~ s{/+}{/}g;
+    $self->{_default}->{url} = "/" unless (exists $self->{_default}->{url} and $self->{_default}->{url});
+    $self->{_default}->{url} =~ s{(?<!:)/+}{/}g;
+
     $self->{_default}->{post_num} = "5" unless (exists $self->{_default}->{post_num} and $self->{_default}->{post_num});
     $self->{_default}->{archive_post_num} = "20" unless (exists $self->{_default}->{archive_post_num} and $self->{_default}->{archive_post_num});
     $self->{_default}->{feed_post_num} = "20" unless (exists $self->{_default}->{feed_post_num} and $self->{_default}->{feed_post_num});
     $self->{_default}->{default_floor} = "blog" unless (exists $self->{_default}->{default_floor} and $self->{_default}->{default_floor});
     $self->{_default}->{date_format} = "gregorian" unless (exists $self->{_default}->{date_format} and $self->{_default}->{date_format});
+    $self->{_default}->{permalink} = ":year/:month/:day/:title/" unless (exists $self->{_default}->{permalink} and $self->{_default}->{permalink});
+    $self->{_default}->{default_markup} = "markdown" unless (exists $self->{_default}->{default_markup} and $self->{_default}->{default_markup});
+    $self->{_default}->{default_extension} = "md" unless (exists $self->{_default}->{default_extension} and $self->{_default}->{default_extension});
+    $self->{_default}->{static} = "/static" unless (exists $self->{_default}->{static} and $self->{_default}->{static});
 
     my $glob = catfile($source, 'content', '*');
 
@@ -69,29 +79,30 @@ sub new {
         if ($@)
         {
           carp " # - $floor\.yml have problem, use default configs for floor: $floor";
-          $self->{$floor} = _not_valids($floor, $self);
-          next;
+          $floorconf = _not_valids($floor, $self);
         }
         $self->{$floor} = $floorconf;
         $self->{$floor}->{title} = $floor unless ($self->{$floor}->{title});
-        $self->{$floor}->{description} = $self->{_default}->{description} unless ($self->{$floor}->{description});
         $self->{$floor}->{root} = "$self->{_default}->{root}/$floor/" unless ($self->{$floor}->{root});
         $self->{$floor}->{url} = "$self->{_default}->{url}/$floor/" unless ($self->{$floor}->{url});
-        $self->{$floor}->{static} = $self->{_default}->{static} unless ($self->{$floor}->{static});
-        $self->{$floor}->{imageurl} = $self->{_default}->{imageurl} unless ($self->{$floor}->{imageurl});
-        $self->{$floor}->{author} = $self->{_default}->{author} unless ($self->{$floor}->{author});
-        $self->{$floor}->{email} = $self->{_default}->{email} unless ($self->{$floor}->{email});
-        $self->{$floor}->{template} = $self->{_default}->{template} unless ($self->{$floor}->{template});
-        $self->{$floor}->{lists} = $self->{_default}->{lists} unless ($self->{$floor}->{lists});
-        $self->{$floor}->{namespace} = $self->{_default}->{namespace} unless ($self->{$floor}->{namespace});
-        $self->{$floor}->{date_format} = $self->{_default}->{date_format} unless ($self->{$floor}->{date_format});
-        $self->{$floor}->{post_num} = $self->{_default}->{post_num} unless $self->{$floor}->{post_num};
-        $self->{$floor}->{archive_post_num} = $self->{_default}->{archive_post_num} unless $self->{$floor}->{archive_post_num};
-        $self->{$floor}->{feed_post_num} = $self->{_default}->{feed_post_num} unless $self->{$floor}->{feed_post_num};
+        $self->{$floor}->{static} = "$self->{$floor}->{root}/static/" unless ($self->{$floor}->{static});
       } else
       {
         $self->{$floor} = _not_valids($floor, $self);
       }
+
+      $self->{$floor}->{url} =~ s{(?<!:)/+}{/}g;
+      #$self->{$floor}->{url} =~ s{((?:(?!.*?:)/+))}{/}g;
+      $self->{$floor}->{root} =~ s{^(.*?):/+}{/}g;
+      $self->{$floor}->{root} =~ s{/+}{/}g;
+      $self->{$floor}->{static} =~ s{/+}{/}g;
+
+      foreach my $key (keys %{ $self->{_default} })
+      {
+        $self->{$floor}->{$key} = $self->{_default}->{$key}
+        if (not exists $self->{$floor}->{$key});
+      }
+
     }
 
     return $self;
@@ -104,18 +115,9 @@ sub _not_valids {
     title => "$floor",
     root => "$self->{_default}->{root}/$floor/",
     url => "$self->{_default}->{url}/$floor",
-    author => $self->{_default}->{author},
-    permalink => ":year/:month/:day/:title/",
-    default_markup => "markdown",
-    post_num => "5",
-    archive_post_num => "20",
-    feed_post_num => "20",
-    static => $self->{_default}->{static},
-    imageurl => $self->{_default}->{imageurl},
-    template => $self->{_default}->{template},
-    lists => $self->{_default}->{lists},
-    namespace => $self->{_default}->{namespace},
+    static => "$self->{_default}->{root}/$floor/static",
   };
+
   return $configs;
 }
 
