@@ -1,5 +1,4 @@
 package Mira::Plugin::Date::Jalali;
-$Mira::Plugin::Date::Jalali::VERSION = '00.07.56';
 
 use strict;
 use warnings;
@@ -8,7 +7,7 @@ use Carp;
 
 use utf8;
 use 5.012;
-
+our $VERSION = $Mira::VERSION;
 
 use Exporter 'import';
 our @EXPORT_OK = qw(jalali gregorian);
@@ -228,7 +227,9 @@ separate methods
 
 =head1 AUTHOR
 
-kiamazi C<kiavash@cpan.org>
+Kiavash
+
+Ahmad Anvari <http://www.anvari.org/bio/>
 
 Redistributed by : Ehsan Golpayegani <http://www.golpayegani.com>
 
