@@ -1,10 +1,10 @@
 package Mira::View::Archive;
-$Mira::View::Archive::VERSION = '0.07';
 
 use strict;
 use warnings;
 use utf8;
 use 5.012;
+our $VERSION = $Mira::VERSION;
 
 use File::Spec;
 use File::Spec::Functions;
@@ -16,15 +16,16 @@ sub template {
 
   my $allposts = $switches{posts}; #all utids reverse sorted
   my $allentries = $switches{allentries}; #all entries data hash
-  my $floors = $switches{floors};
+#  my $floors = $switches{floors};
   my $config = $switches{config}; #configs
   my $pensource = $switches{pensource};
-  my $lists = $switches{lists};
+  my $archives = $switches{archives};
   my $floor_data = $switches{floor_data};
   my $build = $switches{build};
 
-  foreach my $floor (keys %$lists) {
-  	foreach my $archive ( keys %{ $lists->{$floor} } ) {
+  foreach my $floor (keys %$archives) {
+    my $arch_stct = {%{$archives->{$floor}->{list}}, %{$archives->{$floor}->{date}}};
+  	foreach my $archive ( keys %$arch_stct ) {
   		my $archive_template_root =
       (
       -f catfile($pensource,'template',$config->{$floor}->{template},'archive.tt2')
@@ -34,10 +35,10 @@ sub template {
   		? catdir($pensource,'template',$config->{$floor}->{template})
       : catdir($pensource,'template', $config->{_default}->{template});
 
-  		foreach my $list ( keys %{ $lists->{$floor}->{$archive} } ) {
-  			my $show_list_url = $lists->{$floor}->{$archive}->{$list}->{url};
+  		foreach my $list ( keys %{ $arch_stct->{$archive} } ) {
+  			my $show_list_url = $arch_stct->{$archive}->{$list}->{url};
         my @show_list_address = split (m:/:, $show_list_url);
-  			my @utids = @{$lists->{$floor}->{$archive}->{$list}->{posts}};
+  			my @utids = @{$arch_stct->{$archive}->{$list}->{posts}};
   			@utids = reverse sort @utids;
 
   			my $archive_index = Template->new({
@@ -50,31 +51,35 @@ sub template {
   				}) || die "$Template::ERROR\n";
 
         my $vars = {
-          MainTITLE => $config->{_default}->{title},
+          MainTITLE       => $config->{_default}->{title},
           MainDESCRIPTION => $config->{_default}->{description},
-          MainURL => $config->{_default}->{url},
-          MainROOT => $config->{_default}->{root},
-          MainSTATIC => $config->{_default}->{static},
-       	  MainIMAGEURL => $config->{_default}->{imageurl},
-          MainAUTHOR => $config->{_default}->{author},
-          MainEMAIL => $config->{_default}->{email},
-          TITLE => $config->{$floor}->{title},
-          DESCRIPTION => $config->{$floor}->{description},
-          URL => $config->{$floor}->{url},
-          ROOT => $config->{$floor}->{root},
-          STATIC => $config->{$floor}->{static},
-          IMAGEURL => $config->{$floor}->{imageurl},
-          AUTHOR => $config->{$floor}->{author},
-          EMAIL => $config->{$floor}->{email},
+          MainURL         => $config->{_default}->{url},
+          MainROOT        => $config->{_default}->{root},
+          MainSTATIC      => $config->{_default}->{static},
+       	  MainIMAGEURL    => $config->{_default}->{imageurl},
+          MainAUTHOR      => $config->{_default}->{author},
+          MainEMAIL       => $config->{_default}->{email},
+          TITLE           => $config->{$floor}->{title},
+          DESCRIPTION     => $config->{$floor}->{description},
+          URL             => $config->{$floor}->{url},
+          ROOT            => $config->{$floor}->{root},
+          STATIC          => $config->{$floor}->{static},
+          IMAGEURL        => $config->{$floor}->{imageurl},
+          AUTHOR          => $config->{$floor}->{author},
+          EMAIL           => $config->{$floor}->{email},
+
           ArchiveTITLE => $list,
           PageTITLE => "$config->{$floor}->{title} - $list",
-          Entries  => $allentries,
-          Floors => $floor_data,
-          Archives => $lists->{$floor},
-          MAIN => $config->{_default},
-          SITE => $config->{$floor},
-          BUILD => $build,
-          FarsiNum => bless(\&farsinum, 'mira'),
+
+          ENTRIES         => $allentries,
+          FLOORS          => $floor_data,
+          ARCHIVES        => {%{$archives->{$floor}->{list}}, %{$archives->{$floor}->{date}}}, #$archives->{$floor}->{list},
+
+          MAIN            => $config->{_default},
+          SITE            => $config->{$floor},
+          BUILD           => $build,
+
+          FarsiNum        => bless(\&farsinum, 'mira'),
         };
 
         sub farsinum {
@@ -83,58 +88,58 @@ sub template {
           return $string;
         }
 
-        $vars->{MainURL} =~ s"(?<!http:)/+"/"g;
-        $vars->{MainURL} =~ s"/$""g;
+        #$vars->{MainURL} =~ s"(?<!http:)/+"/"g;
+        $vars->{MainURL} =~ s{(?<!:)/+}{/}g;
+        $vars->{MainURL} =~ s{/$}{}g;
 
-        $vars->{MainROOT} =~ s"^http:/+"/"g;
+        $vars->{MainROOT} =~ s{^(.*?):/+}{/}g;
         $vars->{MainROOT} = "/" . $vars->{MainROOT} if $vars->{MainROOT} !~ m:^/:;
-        $vars->{MainROOT} =~ s"/+"/"g;
-        $vars->{MainROOT} =~ s"/$""g unless $vars->{MainROOT} eq "/";
+        $vars->{MainROOT} =~ s{/+}{/}g;
+        $vars->{MainROOT} =~ s{/$}{}g unless $vars->{MainROOT} eq "/";
 
-        $vars->{URL} =~ s"(?<!http:)/+"/"g;
-        $vars->{URL} =~ s"/$""g;
+        #$vars->{URL} =~ s"(?<!http:)/+"/"g;
+        $vars->{URL} =~ s{(?<!:)/+}{/}g;
+        $vars->{URL} =~ s{/$}{}g;
 
-        $vars->{ROOT} =~ s"^http:/+"/"g;
+        $vars->{ROOT} =~ s{^(.*?):/+}{/}g;
         $vars->{ROOT} = "/" . $vars->{ROOT} if $vars->{ROOT} !~ m:^/:;
-        $vars->{ROOT} =~ s"/+"/"g;
-        $vars->{ROOT} =~ s"/$""g unless $vars->{ROOT} eq "/";
+        $vars->{ROOT} =~ s{/+}{/}g;
+        $vars->{ROOT} =~ s{/$}{}g unless $vars->{ROOT} eq "/";
 
-        foreach my $archive (keys %{$lists->{$floor}})
+        foreach my $field (keys %{$archives->{$floor}->{list}})
         {
-          next if $archive eq 'date';
-          next if $archive eq 'jdate';
-          $vars->{$archive} = [
+          $vars->{$field} = [
           reverse sort
           {
             $#{$a->{posts}} <=> $#{$b->{posts}}
             or
             $a->{name} cmp $b->{name}
           }
-          (values %{ $lists->{$floor}->{$archive} })
+          (values %{ $archives->{$floor}->{list}->{$field} })
           ];
         }
 
-        if ($lists->{$floor}->{date})
+        if ($archives->{$floor}->{date}->{date})
         {
-          $vars->{Date} = [
+          $vars->{DATE} = [
           reverse sort
           {
             $a->{_number} <=> $b->{_number}
           }
-          (values %{ $lists->{$floor}->{date} })
+          (values %{ $archives->{$floor}->{date} })
           ];
         }
 
-        if ($lists->{$floor}->{jdate})
+        if ($archives->{$floor}->{date}->{jdate})
         {
-          $vars->{JDate} = [
+          $vars->{JDATE} = [
           reverse sort
           {
             $a->{_year} <=> $b->{_year}
             or
             $a->{_number} <=> $b->{_number}
           }
-          (values %{ $lists->{$floor}->{jdate} })
+          (values %{ $archives->{$floor}->{jdate} })
           ];
         }
 
