@@ -1,10 +1,10 @@
 package Mira::View::Main;
-$Mira::View::Main::VERSION = '0.07';
 
 use strict;
 use warnings;
 use utf8;
 use 5.012;
+our $VERSION = $Mira::VERSION;
 
 use File::Spec;
 use File::Spec::Functions;
@@ -16,7 +16,7 @@ sub template {
 
   my $allposts = $switches{posts}; #all utids reverse sorted
   my $allentries = $switches{allentries}; #all entries data hash
-  my $floors = $switches{floors};
+#  my $floors = $switches{floors};
   my $config = $switches{config}; #configs
   my $pensource = $switches{pensource};
   my $floor_data = $switches{floor_data};
@@ -56,13 +56,14 @@ sub template {
      return $string;
    }
 
-   $vars->{MainURL} =~ s"(?<!http:)/+"/"g;
-   $vars->{MainURL} =~ s"/$""g;
+   #$vars->{MainURL} =~ s"(?<!http:)/+"/"g;
+   $vars->{MainURL} =~ s{(?<!:)/+}{/}g;
+   $vars->{MainURL} =~ s{/$}{}g;
 
-   $vars->{MainROOT} =~ s"^http:/+"/"g;
+   $vars->{MainROOT} =~ s{^(.*?):/+}{/}g;
    $vars->{MainROOT} = "/" . $vars->{MainROOT} if $vars->{MainROOT} !~ m:^/:;
-   $vars->{MainROOT} =~ s"/+"/"g;
-   $vars->{MainROOT} =~ s"/$""g unless $vars->{MainROOT} eq "/";
+   $vars->{MainROOT} =~ s{/+}{/}g;
+   $vars->{MainROOT} =~ s{/$}{}g unless $vars->{MainROOT} eq "/";
 
 
   my $index = catfile($pensource, 'public', $config->{_default}->{root}, 'index.html');
